summaryrefslogtreecommitdiff
path: root/deps/v8/src/objects/osr-optimized-code-cache.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/src/objects/osr-optimized-code-cache.h')
-rw-r--r--deps/v8/src/objects/osr-optimized-code-cache.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/deps/v8/src/objects/osr-optimized-code-cache.h b/deps/v8/src/objects/osr-optimized-code-cache.h
index 99c148a7e1..62e135b02e 100644
--- a/deps/v8/src/objects/osr-optimized-code-cache.h
+++ b/deps/v8/src/objects/osr-optimized-code-cache.h
@@ -32,7 +32,7 @@ class V8_EXPORT OSROptimizedCodeCache : public WeakFixedArray {
// kOSRCodeCacheInitialLength entries.
static void AddOptimizedCode(Handle<NativeContext> context,
Handle<SharedFunctionInfo> shared,
- Handle<Code> code, BailoutId osr_offset);
+ Handle<Code> code, BytecodeOffset osr_offset);
// Reduces the size of the OSR code cache if the number of valid entries are
// less than the current capacity of the cache.
static void Compact(Handle<NativeContext> context);
@@ -40,10 +40,10 @@ class V8_EXPORT OSROptimizedCodeCache : public WeakFixedArray {
static void Clear(NativeContext context);
// Returns the code corresponding to the shared function |shared| and
// BailoutId |offset| if an entry exists in the cache. Returns an empty
// object otherwise.
- Code GetOptimizedCode(Handle<SharedFunctionInfo> shared, BailoutId osr_offset,
- Isolate* isolate);
+ Code GetOptimizedCode(Handle<SharedFunctionInfo> shared,
+ BytecodeOffset osr_offset, Isolate* isolate);
// Remove all code objects marked for deoptimization from OSR code cache.
void EvictMarkedCode(Isolate* isolate);
@@ -58,12 +58,13 @@ class V8_EXPORT OSROptimizedCodeCache : public WeakFixedArray {
// Helper functions to get individual items from an entry in the cache.
Code GetCodeFromEntry(int index);
SharedFunctionInfo GetSFIFromEntry(int index);
- BailoutId GetBailoutIdFromEntry(int index);
+ BytecodeOffset GetBytecodeOffsetFromEntry(int index);
- inline int FindEntry(Handle<SharedFunctionInfo> shared, BailoutId osr_offset);
+ inline int FindEntry(Handle<SharedFunctionInfo> shared,
+ BytecodeOffset osr_offset);
inline void ClearEntry(int src, Isolate* isolate);
inline void InitializeEntry(int entry, SharedFunctionInfo shared, Code code,
- BailoutId osr_offset);
+ BytecodeOffset osr_offset);
inline void MoveEntry(int src, int dst, Isolate* isolate);
OBJECT_CONSTRUCTORS(OSROptimizedCodeCache, WeakFixedArray);
@@ -40,10 +40,10 @@ class V8_EXPORT OSROptimizedCodeCache : public WeakFixedArray {
static void Clear(NativeContext context);
// Returns the code corresponding to the shared function |shared| and
- // BailoutId |offset| if an entry exists in the cache. Returns an empty
+ // BytecodeOffset |offset| if an entry exists in the cache. Returns an empty
// object otherwise.